==> qtjambi-qt3drender-5.15.4-sources.jar: io/qt/qt3d/render/QRenderStateSet.java <==
package io.qt.qt3d.render;


/**
 * <p>FrameGraph node offers a way of specifying a set of QRenderState objects to be applied during the execution of a framegraph branch</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qrenderstateset.html">Qt3DRender::QRenderStateSet</a></p>
 */
public class QRenderStateSet extends io.qt.qt3d.render.QFrameGraphNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderStateSet.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRenderStateSet(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderStateSet() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QRenderStateSet(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderStateSet instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderstateset.html#addRenderState">Qt3DRender::QRenderStateSet::addRenderState(Qt3DRender::QRenderState*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addRenderState(io.qt.qt3d.render.QRenderState state){
        addRenderState_native_Qt3DRender_QRenderState_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(state));
    }
    
    @io.qt.QtUninvokable
    private native void addRenderState_native_Qt3DRender_QRenderState_ptr(long __this__nativeId, long state);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#createNodeCreationChange">Qt3DCore::QNode::createNodeCreationChange()const</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange() throws io.qt.QNoImplementationException {
        return createNodeCreationChange_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    private static io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange_native_constfct(long __this__nativeId) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderstateset.html#removeRenderState">Qt3DRender::QRenderStateSet::removeRenderState(Qt3DRender::QRenderState*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeRenderState(io.qt.qt3d.render.QRenderState state){
        removeRenderState_native_Qt3DRender_QRenderState_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(state));
    }
    
    @io.qt.QtUninvokable
    private native void removeRenderState_native_Qt3DRender_QRenderState_ptr(long __this__nativeId, long state);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderstateset.html#renderStates">Qt3DRender::QRenderStateSet::renderStates()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QRenderState> renderStates(){
        return renderStates_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QRenderState> renderStates_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderStateSet(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRenderStateSet(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRenderStateSet instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QRenderStateSet.java <==
package io.qt.qt3d.render;


/**
 * <p>FrameGraph node offers a way of specifying a set of QRenderState objects to be applied during the execution of a framegraph branch</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qrenderstateset.html">Qt3DRender::QRenderStateSet</a></p>
 */
public class QRenderStateSet extends io.qt.qt3d.render.QFrameGraphNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QRenderStateSet.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QRenderStateSet(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QRenderStateSet() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QRenderStateSet(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QRenderStateSet instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderstateset.html#addRenderState">Qt3DRender::QRenderStateSet::addRenderState(Qt3DRender::QRenderState*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addRenderState(io.qt.qt3d.render.QRenderState state){
        addRenderState_native_Qt3DRender_QRenderState_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(state));
    }
    
    @io.qt.QtUninvokable
    private native void addRenderState_native_Qt3DRender_QRenderState_ptr(long __this__nativeId, long state);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#createNodeCreationChange">Qt3DCore::QNode::createNodeCreationChange()const</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange() throws io.qt.QNoImplementationException {
        return createNodeCreationChange_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    private static io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange_native_constfct(long __this__nativeId) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderstateset.html#removeRenderState">Qt3DRender::QRenderStateSet::removeRenderState(Qt3DRender::QRenderState*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeRenderState(io.qt.qt3d.render.QRenderState state){
        removeRenderState_native_Qt3DRender_QRenderState_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(state));
    }
    
    @io.qt.QtUninvokable
    private native void removeRenderState_native_Qt3DRender_QRenderState_ptr(long __this__nativeId, long state);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qrenderstateset.html#renderStates">Qt3DRender::QRenderStateSet::renderStates()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QRenderState> renderStates(){
        return renderStates_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QRenderState> renderStates_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QRenderStateSet(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QRenderStateSet(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QRenderStateSet instance, QDeclarativeConstructor constructor);
    
}
